@@ -1,12 +1,12 @@
 package HTML::FormWidgets::Slider;
 
-# @(#)$Id: Slider.pm 138 2009-02-22 19:27:59Z pjf $
+# @(#)$Id: Slider.pm 154 2009-04-09 17:04:48Z pjf $
 
 use strict;
 use warnings;
 use parent qw(HTML::FormWidgets);
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 138 $ =~ /\d+/g );
+use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 154 $ =~ /\d+/g );
 
 __PACKAGE__->mk_accessors( qw(display element hide js_obj mode offset range
                               snap steps wheel) );
@@ -81,63 +81,6 @@ sub _render {
 
 __END__
 
-=pod
-
-=head1 Name
-
-HTML::FormWidgets::Slider - Dragable slider
-
-=head1 Version
-
-0.1.$Revision: 138 $
-
-=head1 Synopsis
-
-=head1 Description
-
-Dragable slider that returns an integer value
-
-=head1 Subroutines/Methods
-
-=head1 Diagnostics
-
-=head1 Configuration and Environment
-
-=head1 Dependencies
-
-=over 3
-
-=item L<Class::Accessor::Fast>
-
-=back
-
-=head1 Incompatibilities
-
-There are no known incompatibilities in this module
-
-=head1 Bugs and Limitations
-
-There are no known bugs in this module.
-Please report problems to the address below.
-Patches are welcome
-
-=head1 Author
-
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
-
-=head1 License and Copyright
-
-Copyright (c) 2008 Peter Flanigan. All rights reserved
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. See L<perlartistic>
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE
-
-=cut
-
 # Local Variables:
 # mode: perl
 # tab-width: 3
